@@ -74,7 +74,7 @@ pub enum PidInfoFlavor {
     TaskInfo = 4,
     /// struct `proc_threadinfo`
     ThreadInfo = 5,
-    /// list if int thread ids
+    /// list thread ids
     ListThreads = 6,
     /// TBD what type `RegionInfo` is - string?
     RegionInfo = 7,
@@ -205,11 +205,11 @@ pub fn listpidspath(proc_types: ProcType, path: &str) -> Result<Vec<u32>, String
 }
 
 /// Get info about a process, task, thread or work queue by specifying the appropriate type for `T`:
-/// - `BSDInfo`
-/// - `TaskInfo`
-/// - `TaskAllInfo`
-/// - `ThreadInfo`
-/// - `WorkQueueInfo`
+/// - `BSDInfo` - see struct `proc_bsdinfo` in generated `osx_libproc_bindings.rs`
+/// - `TaskInfo` - see struct `proc_taskinfo` in generated `osx_libproc_bindings.rs`
+/// - `TaskAllInfo` - see struct `TaskAllInfo` in `task_info.rs` that contains the two structs above
+/// - `ThreadInfo` - see struct `proc_threadinfo` in generated `osx_libproc_bindings.rs`
+/// - `WorkQueueInfo` - see struct `proc_workqueueinfo` in generated `osx_libproc_bindings.rs`
 ///
 /// # Errors
 ///
@@ -219,17 +219,47 @@ pub fn listpidspath(proc_types: ProcType, path: &str) -> Result<Vec<u32>, String
 ///
 /// ```
 /// use std::io::Write;
-/// use libproc::libproc::proc_pid::pidinfo;
-/// use libproc::libproc::bsd_info::BSDInfo;
+/// use libproc::proc_pid::pidinfo;
+/// use libproc::bsd_info::BSDInfo;
+/// use libproc::task_info::{TaskAllInfo, TaskInfo};
 /// use std::process;
+/// use libproc::thread_info::ThreadInfo;
+/// use libproc::work_queue_info::WorkQueueInfo;
 ///
 /// let pid = process::id() as i32;
 ///
-/// // Get the `BSDInfo` for Process of pid 0
+/// // Get the `BSDInfo` for process with pid 0
 /// match pidinfo::<BSDInfo>(pid, 0) {
 ///     Ok(info) => assert_eq!(info.pbi_pid as i32, pid),
 ///     Err(err) => eprintln!("Error retrieving process info: {}", err)
 /// };
+///
+/// // Get the `TaskInfo` for process with pid 0
+/// match pidinfo::<TaskInfo>(pid, 0) {
+///     Ok(info) => assert!(info.pti_threadnum  > 0),
+///     Err(err) => eprintln!("Error retrieving process info: {}", err)
+/// };
+///
+/// // Get the `TaskAllInfo` for process with pid 0
+/// match pidinfo::<TaskAllInfo>(pid, 0) {
+///     Ok(info) => {
+///         assert_eq!(info.pbsd.pbi_pid as i32, pid);
+///         assert!(info.ptinfo.pti_threadnum  > 0);
+///     }
+///     Err(err) => eprintln!("Error retrieving process info: {}", err)
+/// };
+///
+/// // Get the `ThreadInfo` for process with pid 0
+/// match pidinfo::<ThreadInfo>(pid, 0) {
+///     Ok(info) => assert!(!info.pth_name.is_empty()),
+///     Err(err) => eprintln!("Error retrieving process info: {}", err)
+/// };
+///
+/// // Get the `WorkQueueInfo` for process with pid 0
+/// match pidinfo::<WorkQueueInfo>(pid, 0) {
+///     Ok(info) => assert!(info.pwq_nthreads > 0),
+///     Err(err) => eprintln!("Error retrieving process info: {}", err)
+/// };
 /// ```
 #[cfg(target_os = "macos")]
 pub fn pidinfo<T: PIDInfo>(pid: i32, arg: u64) -> Result<T, String> {
@@ -670,25 +700,19 @@ mod test {
         };
     }
 
-    #[ignore]
     #[cfg(target_os = "macos")]
     #[test]
     fn threadinfo_test() {
-        let pid = process::id() as i32;
-
-        match pidinfo::<ThreadInfo>(pid, 0) {
-            Ok(info) => assert!(info.pth_user_time > 0),
+        match pidinfo::<ThreadInfo>(0, 0) {
+            Ok(info) => assert!(!info.pth_name.is_empty()),
             Err(e) => panic!("Error retrieving ThreadInfo: {}", e),
         };
     }
 
-    #[ignore]
     #[cfg(target_os = "macos")]
     #[test]
     fn workqueueinfo_test() {
-        let pid = process::id() as i32;
-
-        match pidinfo::<WorkQueueInfo>(pid, 0) {
+        match pidinfo::<WorkQueueInfo>(1, 0) {
             Ok(info) => assert!(info.pwq_nthreads > 0),
             Err(e) => panic!("{}: {}", "Error retrieving WorkQueueInfo", e),
         };
